@@ -1,3 +1,6 @@
+# SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
+# SPDX-License-Identifier: MIT
+
 import time
 import board
 import busio
@@ -11,8 +14,27 @@ sensor = adafruit_bno055.BNO055_I2C(i2c)
 # uart = busio.UART(board.TX, board.RX)
 # sensor = adafruit_bno055.BNO055_UART(uart)
 
+last_val = 0xFFFF
+
+
+def temperature():
+    global last_val  # pylint: disable=global-statement
+    result = sensor.temperature
+    if abs(result - last_val) == 128:
+        result = sensor.temperature
+        if abs(result - last_val) == 128:
+            return 0b00111111 & result
+    last_val = result
+    return result
+
+
 while True:
     print("Temperature: {} degrees C".format(sensor.temperature))
+    """
+    print(
+        "Temperature: {} degrees C".format(temperature())
+    )  # Uncomment if using a Raspberry Pi
+    """
     print("Accelerometer (m/s^2): {}".format(sensor.acceleration))
     print("Magnetometer (microteslas): {}".format(sensor.magnetic))
     print("Gyroscope (rad/sec): {}".format(sensor.gyro))
